import { request } from '@/common/utils'
import type { CraftParamsResponse, TasksGroupByChannel, Task } from './task'
import type { PLCResponse } from './plc'
import type { Devices } from './device'
import type { CraftModel } from './craftModel'
import type { Problem } from './problem'
import type { ReportingRecord } from './reporting'

export interface BaseResponse<T = any> {
  code: number
  data: T
  msg: string
}

export interface ListResponse<T = any> {
  code: number
  data: T
  msg: string
  total: number
}

export interface TaskListParams {
  /** 1未完成2今天未完成3已完成 */
  type: 1 | 2 | 3
  /** 通道号 不传查所有通道的 */
  channel?: number
  /** 从第几个开始查，从0开始 */
  offset: number
  /** 查多少条 */
  limit: number
  /** 设备id */
  deviceID: string
}

/**
 * 获取任务列表
 * @param params
 */
export function getTaskList(params: TaskListParams) {
  return request<BaseResponse<TasksGroupByChannel>>({
    url: '/api-s/v1/reportWork/taskList',
    method: 'get',
    params
  })
}

export interface TaskInfoParams {
  /** 设备id */
  deviceID: string
  /** 工序id */
  procedureID: number
}

/**
 * 获取任务详情
 * @param params
 */
export function getTaskInfo(params: TaskInfoParams) {
  return request<BaseResponse<Task>>({
    url: '/api-s/v1/reportWork/taskInfo',
    method: 'get',
    params
  })
}

export interface ProductProgressParams {
  channel: number
  procedureId?: number
}

/**
 * 获取PLC运行数据
 * @param params
 */
export function getProductProgress(params: ProductProgressParams) {
  return request<BaseResponse<PLCResponse>>({
    url: '/v1/plc/productProgress',
    method: 'post',
    data: params
  })
}
export interface CraftParamsParams {
  id: number
}

/**
 * 获取工艺参数
 * @param params
 */
export function getCraftParams(params: CraftParamsParams) {
  return request<BaseResponse<CraftParamsResponse>>({
    url: `v1/task/start/${params.id}`,
    method: 'get',
    data: params
  })
}

export interface SendProcessParamsParams {
  procedureId: number
}

/**
 * 下发工艺参数
 * @param params
 */
export function sendProcessParams(params: SendProcessParamsParams) {
  return request<BaseResponse>({
    url: `v1/task/sendProcessParams`,
    method: 'post',
    data: params
  })
}

export interface FinishTaskParams {
  id: number
}

/**
 * 结束任务
 * @param params
 */
export function finishTask(params: FinishTaskParams) {
  return request<BaseResponse>({
    url: `v1/task/finish/${params.id}`,
    method: 'put',
    data: params
  })
}

export interface ProcedureUpdateParams {
  isFinish: boolean
  isProcessing: boolean
  workOrderProcedureID: number
}

/**
 * 开始任务/完成任务 (原 获取工艺参数/结束任务)
 * @param params
 */
export function procedureUpdate(params: ProcedureUpdateParams) {
  return request<BaseResponse>({
    url: `/api-s/v1/reportWork/procedureUpdate`,
    method: 'post',
    data: params
  })
}

/**
 * 获取当前面板绑定的设备列表
 */
export function getDeviceList() {
  return request<BaseResponse<Devices>>({
    url: `/api-s/v1/reportWork/deviceList`,
    method: 'get'
  })
}

export interface SetCurrentDeviceParams {
  currentDeviceID: string
}

/**
 * 设定当前设备
 */
export function apiSetCurrentDevice(data: SetCurrentDeviceParams) {
  return request<BaseResponse>({
    url: `/api-s/v1/reportWork/setCurrentDeviceId`,
    method: 'post',
    data
  })
}

export interface SetCurrentDeviceConfigParams {
  needSetProcessParams: boolean
}

/**
 * 设定当前设备配置
 */
export function apiSetCurrentDeviceConfig(data: SetCurrentDeviceConfigParams) {
  return request<BaseResponse>({
    url: `/v1/device/config`,
    method: 'post',
    data
  })
}

export interface CraftModelListParams {
  procedureId: number
  page: number
  pageSize: number
}

/**
 * 获取工艺模型列表
 * @param params
 */
export function apiGetCraftModelList(params: CraftModelListParams) {
  return request<ListResponse<CraftModel[]>>({
    url: '/v1/processModel/list',
    method: 'get',
    params
  })
}

export interface UpdateCraftPrams {
  procedureId: number
}

/**
 * 更新工艺模型
 * @param params
 */
export function updateCraftParams(params: UpdateCraftPrams) {
  return request<BaseResponse>({
    url: '/v1/task/updateProcessParams',
    method: 'post',
    data: params
  })
}

/**
 * 获取问题诊断问题列表
 */
// export function apiGetProblemList() {
//   return request<BaseResponse<Problem[]>>({
//     url: '/v1/system/problemList',
//     method: 'get'
//   })
// }

export interface ReportingRecordListParams {
  page?: number
  pageSize?: number
  workOrderProcedureID: number
}

/**
 * 获取报工记录列表
 */
export function apiGetReportingRecordList(params: ReportingRecordListParams) {
  return request<ListResponse<ReportingRecord[]>>({
    url: '/api-s/v1/reportWork/list',
    method: 'get',
    params
  })
}

export interface ReportWorkParams {
  workOrderProcedureID: number
  reportAmount: number
  workerID: string
  workerName: string
}

/**
 * 报工
 */
export function apiReportWork(params: ReportWorkParams) {
  return request<BaseResponse>({
    url: '/api-s/v1/reportWork/report',
    method: 'post',
    data: params
  })
}

/**
 * 获取验证码
 */
export function getCaptcha() {
  return request({
    url: '/api/base/captcha',
    method: 'post'
  })
}

export interface loginParams {
  username: string
  password: string
  captcha: string
  captchaId: string
}
/**
 * 登录
 */
export function login(params: loginParams) {
  return request({
    url: '/api/base/login',
    method: 'post',
    data: params
  })
}

export interface qualityParams {
  reportAmount: number
  workOrderProcedureID: number
  workerID: string
  workerName: string
}
/**
 * 看板质检
 */
export function bulletinQualityInspection(params: qualityParams) {
  return request({
    url: '/api-s/v1/reportWork/bulletinQualityInspection',
    method: 'post',
    data: params
  })
}

export interface getQualityParams {
  workOrderId: string
  procedureId: string
}
/**
 * 看板获取质检信息
 */
export function getQualityInspection(params: getQualityParams) {
  return request({
    url: '/api-s/v1/reportWork/bulletinGetQualityInspection',
    method: 'post',
    data: params
  })
}

export interface bulletinReportParams {
  reportAmount: number
  workOrderProcedureID: number
  workerID: string
  workerName: string
  ids: any[]
}
/**
 * 看板报工
 */
export function bulletinReport(params: bulletinReportParams) {
  return request({
    url: '/api-s/v1/reportWork/bulletinReport',
    method: 'post',
    data: params
  })
}

type basicType = number | null | string | undefined
export interface qualityProcedureParams {
  projectId: basicType
  workOrderId: basicType
  status: basicType
  page: number
  pageSize: number
}

/*
 *  获取质检工序
 * */
export function getQualityProcedureApi(params: qualityProcedureParams) {
  return request({
    url: '/api-s/v1/app/getQualityProcedure',
    method: 'post',
    data: params
  })
}
export interface IPage {
  page: number
  pageSize: number
}
/**
 * 获取所有的项目
 * */
export function getProjectApi(params: IPage) {
  return request({
    url: '/api-s/v1/project/projectList',
    method: 'post',
    data: params
  })
}
/**
 * 根据项目获取所有产品
 * */
export interface IProduct {
  page: number
  pageSize: number
  projectId: string
}
export function getProductApi(params: IProduct) {
  return request({
    url: '/api-s/v1/app/getProductListByProject',
    method: 'post',
    data: params
  })
}
/**
 * 获取加工人员列表
 * */
export function getWorkerApi(params: IPage) {
  return request({
    url: 'api-s/v1/worker/getWorkerList',
    method: 'post',
    data: params
  })
}

export interface IUpdateQualityProcedureParams {
  id: number
  passAmount: number
  scrappedAmount: number
  workerName: string
}
/**
 * 更新工序质检数据
 * */
export function updateQualityProcedureApi(params: IUpdateQualityProcedureParams) {
  return request({
    url: '/api-s/v1/app/updateQualityProcedure',
    method: 'post',
    data: params
  })
}
export interface IQualityCountParams {
  projectId: string
  productId: string
}
export function qualityCountApi(params: IQualityCountParams) {
  return request({
    url: '/api-s/v1/app/appViewShow',
    method: 'post',
    data: params
  })
}
